nsi.granulate.FileUtils.File

Package nsi :: Package granulate :: Module FileUtils :: Class File |
[hide private]
[frames] | no frames]

# Class File

source code

    object --+
             |
            File

This class is used for file handling

Instance Methods | [hide private]
__init__(self, filename=None, data=None) Sets the filename and the file content | source code
__call__(self) Should be used getData instead of __call___ For this object, call is useless. | source code
getFilename(self) | source code
setFilename(self, filename=None) Set Filename and extract MimeType document | source code
getData(self) | source code
setData(self, data=None) Set Data as a StringIO | source code
getContentType(self) | source code
setContentType(self, mimetype=None) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, filename=None, data=None) (Constructor) | source code
Sets the filename and the file content Overrides: object.__init__